netapp_ontap.models.shelf_bays API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.shelf_bays`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ShelfBaysSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ShelfBays object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `drawer: ShelfBaysDrawer GET POST PATCH`

    The drawer field of the shelf_bays.

  `has_disk: bool GET POST PATCH`

    The has_disk field of the shelf_bays.

  `id: Size GET POST PATCH`

    The id field of the shelf_bays.

    Example: 0

  `state: str GET POST PATCH`

    The state field of the shelf_bays.

    Valid choices:

    - unknown
    - ok
    - error
  `type: str GET POST PATCH`

    The type field of the shelf_bays.

    Valid choices:

    - unknown
    - single_disk
    - multi_lun